@@ -361,25 +361,6 @@ g_network_service_set_scheme (GNetworkService *srv,
   g_object_notify (G_OBJECT (srv), "scheme");
 }
 
-static GList *
-g_network_service_fallback_targets (GNetworkService *srv)
-{
-  GSrvTarget *target;
-  struct servent *entry;
-  guint16 port;
-
-  entry = getservbyname (srv->priv->service, "tcp");
-  port = entry ? g_ntohs (entry->s_port) : 0;
-#ifdef HAVE_ENDSERVENT
-  endservent ();
-#endif
-
-  if (entry == NULL)
-      return NULL;
-
-  target = g_srv_target_new (srv->priv->domain, port, 0, 0);
-  return g_list_append (NULL, target);
-}
 
 #define G_TYPE_NETWORK_SERVICE_ADDRESS_ENUMERATOR (_g_network_service_address_enumerator_get_type ())
 #define G_NETWORK_SERVICE_ADDRESS_ENUMERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), G_TYPE_NETWORK_SERVICE_ADDRESS_ENUMERATOR, GNetworkServiceAddressEnumerator))
@@ -420,26 +401,14 @@ g_network_service_address_enumerator_next (GSocketAddressEnumerator  *enumerator
   if (!srv_enum->srv->priv->targets)
     {
       GList *targets;
-      GError *my_error = NULL;
 
       targets = g_resolver_lookup_service (srv_enum->resolver,
                                            srv_enum->srv->priv->service,
                                            srv_enum->srv->priv->protocol,
                                            srv_enum->srv->priv->domain,
-                                           cancellable, &my_error);
-      if (!targets && g_error_matches (my_error, G_RESOLVER_ERROR,
-                                       G_RESOLVER_ERROR_NOT_FOUND))
-        {
-          targets = g_network_service_fallback_targets (srv_enum->srv);
-          if (targets)
-            g_clear_error (&my_error);
-        }
-
-      if (my_error)
-        {
-          g_propagate_error (error, my_error);
-          return NULL;
-        }
+                                           cancellable, error);
+      if (!targets)
+        return NULL;
 
       srv_enum->srv->priv->targets = targets;
       srv_enum->t = srv_enum->srv->priv->targets;
@@ -509,10 +478,7 @@ g_network_service_address_enumerator_next (GSocketAddressEnumerator  *enumerator
                 srv_enum->error = error;
               else
                 g_error_free (error);
-            }
 
-          if (!ret)
-            {
               g_object_unref (srv_enum->addr_enum);
               srv_enum->addr_enum = NULL;
             }
@@ -577,18 +543,9 @@ next_async_resolved_targets (GObject      *source_object,
 {
   GNetworkServiceAddressEnumerator *srv_enum = user_data;
   GError *error = NULL;
-  GList *targets;
 
-  targets = g_resolver_lookup_service_finish (srv_enum->resolver,
-                                              result, &error);
-
-  if (!targets && g_error_matches (error, G_RESOLVER_ERROR,
-                                   G_RESOLVER_ERROR_NOT_FOUND))
-    {
-      targets = g_network_service_fallback_targets (srv_enum->srv);
-      if (targets)
-        g_clear_error (&error);
-    }
+  srv_enum->srv->priv->targets =
+    g_resolver_lookup_service_finish (srv_enum->resolver, result, &error);
 
   if (error)
     {
@@ -602,7 +559,7 @@ next_async_resolved_targets (GObject      *source_object,
     }
   else
     {
-      srv_enum->t = srv_enum->srv->priv->targets = targets;
+      srv_enum->t = srv_enum->srv->priv->targets;
       next_async_have_targets (srv_enum);
     }
 }
@@ -671,10 +628,7 @@ next_async_have_address (GObject      *source_object,
         srv_enum->error = error;
       else
         g_error_free (error);
-    }
 
-  if (!address)
-    {
       g_object_unref (srv_enum->addr_enum);
       srv_enum->addr_enum = NULL;
 
