@@ -24,7 +24,6 @@
 #include "gseekable.h"
 #include "glibintl.h"
 
-#include "gioalias.h"
 
 /**
  * SECTION:gseekable
@@ -37,42 +36,11 @@
  * 
  **/
 
-
-static void g_seekable_base_init (gpointer g_class);
-
-
-GType
-g_seekable_get_type (void)
-{
-  static GType seekable_type = 0;
-
-  if (!seekable_type)
-    {
-      static const GTypeInfo seekable_info =
-      {
-        sizeof (GSeekableIface), /* class_size */
-	g_seekable_base_init,   /* base_init */
-	NULL,		/* base_finalize */
-	NULL,
-	NULL,		/* class_finalize */
-	NULL,		/* class_data */
-	0,
-	0,              /* n_preallocs */
-	NULL
-      };
-
-      seekable_type =
-	g_type_register_static (G_TYPE_INTERFACE, I_("GSeekable"),
-				&seekable_info, 0);
-
-      g_type_interface_add_prerequisite (seekable_type, G_TYPE_OBJECT);
-    }
-
-  return seekable_type;
-}
+typedef GSeekableIface GSeekableInterface;
+G_DEFINE_INTERFACE (GSeekable, g_seekable, G_TYPE_OBJECT)
 
 static void
-g_seekable_base_init (gpointer g_class)
+g_seekable_default_init (GSeekableInterface *iface)
 {
 }
 
@@ -205,6 +173,3 @@ g_seekable_truncate (GSeekable     *seekable,
 
   return (* iface->truncate_fn) (seekable, offset, cancellable, error);
 }
-
-#define __G_SEEKABLE_C__
-#include "gioaliasdef.c"
