@@ -33,7 +33,6 @@
 #include <gio/gioerror.h>
 #include "glibintl.h"
 
-#include "gioalias.h"
 
 #define g_socket_output_stream_get_type _g_socket_output_stream_get_type
 G_DEFINE_TYPE (GSocketOutputStream, g_socket_output_stream, G_TYPE_OUTPUT_STREAM);
@@ -114,8 +113,9 @@ g_socket_output_stream_write (GOutputStream  *stream,
 {
   GSocketOutputStream *onput_stream = G_SOCKET_OUTPUT_STREAM (stream);
 
-  return g_socket_send (onput_stream->priv->socket, buffer, count,
-			cancellable, error);
+  return g_socket_send_with_blocking (onput_stream->priv->socket,
+				      buffer, count, TRUE,
+				      cancellable, error);
 }
 
 static gboolean
@@ -127,11 +127,12 @@ g_socket_output_stream_write_ready (GSocket *socket,
   GError *error = NULL;
   gssize result;
 
-  result = g_socket_send (stream->priv->socket,
-			  stream->priv->buffer,
-			  stream->priv->count,
-			  stream->priv->cancellable,
-			  &error);
+  result = g_socket_send_with_blocking (stream->priv->socket,
+					stream->priv->buffer,
+					stream->priv->count,
+					FALSE,
+					stream->priv->cancellable,
+					&error);
 
   if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_WOULD_BLOCK))
     return TRUE;
@@ -244,6 +245,3 @@ _g_socket_output_stream_new (GSocket *socket)
 {
   return G_SOCKET_OUTPUT_STREAM (g_object_new (G_TYPE_SOCKET_OUTPUT_STREAM, "socket", socket, NULL));
 }
-
-#define __G_SOCKET_OUTPUT_STREAM_C__
-#include "gioaliasdef.c"
